if (!require (ts, quietly=TRUE))
  stop ("Package ts is needed. Stopping")
cpi <- ts(c(
       3.2958369,
       3.2958369,
       3.4011974,
       3.6109179,
       3.8712010,
       3.8501476,
       3.7841896,
       3.7612001,
       3.7135721,
       3.6888795,
       3.6375862,
       3.6109179,
       3.6109179,
       3.6109179,
       3.5553481,
       3.4965076,
       3.4657359,
       3.4657359,
       3.4011974,
       3.3672958,
       3.4011974,
       3.4011974,
       3.4011974,
       3.3672958,
       3.3322045,
       3.3322045,
       3.3322045,
       3.3322045,
       3.3322045,
       3.3322045,
       3.3322045,
       3.3322045,
       3.3322045,
       3.3322045,
       3.2580965,
       3.2188758,
       3.2188758,
       3.2188758,
       3.2188758,
       3.2188758,
       3.2188758,
       3.2188758,
       3.2580965,
       3.2958369,
       3.2958369,
       3.2958369,
       3.3322045,
       3.3672958,
       3.3322045,
       3.3322045,
       3.3672958,
       3.3672958,
       3.4011974,
       3.3911470,
       3.4045252,
       3.4144426,
       3.4873751,
       3.6480575,
       3.8088822,
       3.9473901,
       4.0943446,
       3.9815491,
       3.9160150,
       3.9337845,
       3.9357395,
       3.9608132,
       3.9702919,
       3.9512437,
       3.9376908,
       3.9376908,
       3.9120230,
       3.8199077,
       3.7111301,
       3.6584202,
       3.6913763,
       3.7160081,
       3.7256934,
       3.7612001,
       3.7424202,
       3.7281002,
       3.7376696,
       3.7864598,
       3.8877303,
       3.9473901,
       3.9646155,
       3.9871305,
       4.0690268,
       4.2031990,
       4.2780540,
       4.2682979,
       4.2780540,
       4.3541414,
       4.3757570,
       4.3832759,
       4.3882572,
       4.3845235,
       4.3993753,
       4.4343819,
       4.4612998,
       4.4693505,
       4.4852599,
       4.4953553,
       4.5064542,
       4.5185224,
       4.5315236,
       4.5485998,
       4.5767707,
       4.6051702,
       4.6463121,
       4.6986605,
       4.7561731,
       4.7986642,
       4.8302586,
       4.8906017,
       4.9952863,
       5.0826357,
       5.1386576,
       5.2016571,
       5.2748217,
       5.3823272,
       5.5089477,
       5.6071222,
       5.6669052,
       5.6985244,
       5.7407911,
       5.7757829,
       5.7941996,
       5.8300457,
       5.8705860),
end = 1988, frequency = 1)
ip <- ts(c(
     -0.10536052,
     -0.10536052,
     -0.10536052,
      0.00000000,
      0.00000000,
      0.00000000,
      0.18232156,
      0.26236426,
      0.26236426,
      0.33647224,
      0.40546511,
      0.40546511,
      0.58778666,
      0.58778666,
      0.53062825,
      0.53062825,
      0.53062825,
      0.58778666,
      0.64185389,
      0.78845736,
      0.91629073,
       1.0296194,
       1.0986123,
       1.0986123,
       1.0647107,
       1.0647107,
       1.2527630,
       1.3083328,
       1.3350011,
       1.4109870,
       1.4816045,
       1.5040774,
       1.5686159,
       1.4586150,
       1.4350845,
       1.5892352,
       1.5260563,
       1.5892352,
       1.7227666,
       1.8082888,
       1.8405496,
       1.9600948,
       2.0668628,
       2.0918641,
       2.0541237,
       2.2192035,
       2.2823824,
       2.3025851,
       2.1400662,
       2.3025851,
       2.3608540,
       2.3223877,
       2.4595888,
       2.5257286,
       2.4595888,
       2.6100698,
       2.7788193,
       2.7850112,
       2.7725887,
       2.6461748,
       2.6946272,
       2.4336134,
       2.6741486,
       2.8507065,
       2.7850112,
       2.8791985,
       2.9391619,
       2.9391619,
       2.9755296,
       3.0819100,
       2.8959119,
       2.7080502,
       2.4595888,
       2.6246686,
       2.7146947,
       2.8564702,
       3.0252911,
       3.1135153,
       2.8791985,
       3.0819100,
       3.2386785,
       3.4594663,
       3.6000482,
       3.7999735,
       3.8774316,
       3.7208625,
       3.5610461,
       3.6737658,
       3.7135721,
       3.6584202,
       3.8044378,
       3.8856790,
       3.9239516,
       4.0036902,
       3.9473901,
       4.0673159,
       4.1108739,
       4.1239034,
       4.0569888,
       4.1697612,
       4.1926805,
       4.1987046,
       4.2780540,
       4.3372907,
       4.4042772,
       4.4908810,
       4.5849675,
       4.6051702,
       4.6615505,
       4.7068238,
       4.6700212,
       4.6841389,
       4.7764753,
       4.8546659,
       4.8397243,
       4.7474204,
       4.8354140,
       4.9122950,
       4.9752698,
       5.0139487,
       4.9947962,
       5.0166550,
       4.9428242,
       5.0003059,
       5.1062157,
       5.1249841,
       5.1362383,
       5.1731196,
       5.2285646),
end = 1988, frequency = 1)
gnp.nom <-  ts(c(
       10.416311,
       10.471638,
       10.485703,
       10.581521,
       10.586584,
       10.561008,
       10.596635,
       10.785187,
       11.008744,
       11.243738,
       11.338572,
       11.424094,
       11.150520,
       11.213171,
       11.351582,
       11.346871,
       11.441429,
       11.482466,
       11.460579,
       11.482466,
       11.543406,
       11.411634,
       11.236117,
       10.969043,
       10.925956,
       11.082973,
       11.187846,
       11.320323,
       11.412508,
       11.346517,
       11.413039,
       11.509700,
       11.732382,
       11.969781,
       12.163123,
       12.255358,
       12.264082,
       12.247737,
       12.351570,
       12.459016,
       12.454822,
       12.559434,
       12.702000,
       12.752742,
       12.806537,
       12.807217,
       12.894107,
       12.946194,
       12.997104,
       13.011061,
       13.089144,
       13.129804,
       13.161771,
       13.236272,
       13.288730,
       13.357293,
       13.437005,
       13.527638,
       13.584747,
       13.669562,
       13.741966,
       13.789296,
       13.913272,
       14.008442,
       14.122480,
       14.202676,
       14.284514,
       14.393696,
       14.503896,
       14.626307,
       14.735076,
       14.820544,
       14.931504,
       14.967980,
       15.040961,
       15.143169,
       15.205523,
       15.258091,
       15.324973,
       15.400779),
end = 1988, frequency = 1)
vel <- ts(c(
       1.7245507,
       1.6409366,
       1.5325569,
       1.6193882,
       1.5993876,
       1.5496879,
       1.4951488,
       1.5368672,
       1.5871923,
       1.6213665,
       1.6292405,
       1.6695918,
       1.4838747,
       1.4838747,
       1.3887912,
       1.3584092,
       1.2612979,
       1.2178757,
       1.1908876,
       1.1474025,
       1.1249296,
       1.0986123,
       1.0851893,
       1.0508216,
       1.0750024,
      0.94390590,
       1.0043016,
      0.96698385,
       1.0006319,
      0.92028275,
      0.91228271,
      0.91228271,
      0.89199804,
      0.83724752,
      0.82855182,
      0.76080583,
      0.75612198,
      0.82417544,
      0.82417544,
      0.72270598,
      0.78390154,
      0.77472717,
      0.72754861,
      0.75141609,
      0.76546784,
      0.63127178,
      0.62593843,
      0.73716407,
      0.76546784,
      0.90421815,
      0.81093022,
      0.77932488,
      0.63127178,
      0.62593843,
      0.70309751,
      0.66782937,
      0.62593843,
      0.66268797,
      0.62057649,
      0.60431597,
      0.66268797,
      0.51879379,
      0.37156356,
      0.21511138,
      0.27763174,
      0.38526240,
      0.39877612,
      0.45107562,
      0.49469624,
      0.41210965,
      0.40546511,
      0.39204209,
      0.45742485,
      0.59883650,
      0.55961579,
      0.47623418,
      0.31481074,
      0.14842001,
      0.18232156,
      0.28517894,
      0.26236426,
      0.34358970,
      0.45107562,
      0.44468582,
      0.45107562,
      0.41210965,
      0.46373402,
      0.50681760,
      0.51879379,
      0.47623418,
      0.51879379,
      0.54232429,
      0.52472853,
      0.53649337,
      0.52472853,
      0.53649337,
      0.54232429,
      0.56531381,
      0.54232429,
      0.54232429,
      0.54812141,
      0.54812141,
      0.58079485,
      0.61094334,
      0.64323177,
      0.63370211,
      0.62605631,
      0.64658878,
      0.66931558,
      0.69706753,
      0.71243155,
      0.70791578,
      0.74387346,
      0.70900627,
      0.69009857,
      0.71078082,
      0.70686455,
      0.68820448,
      0.67576289,
      0.66780240),
end = 1988, frequency = 1)
emp <- ts(c(
       10.024687,
       10.034165,
       10.082972,
       10.013283,
       9.9571231,
       10.035568,
       10.048843,
       10.069171,
       10.116419,
       10.200290,
       10.236704,
       10.272358,
       10.302264,
       10.325679,
       10.334328,
       10.372741,
       10.426706,
       10.444968,
       10.411690,
       10.465158,
       10.484641,
       10.496234,
       10.530308,
       10.553153,
       10.533668,
       10.532390,
       10.580607,
       10.598733,
       10.662235,
       10.643948,
       10.616413,
       10.560178,
       10.624590,
       10.690922,
       10.682973,
       10.716238,
       10.746433,
       10.747122,
       10.753083,
       10.776662,
       10.730728,
       10.661017,
       10.576177,
       10.571573,
       10.624979,
       10.657965,
       10.707952,
       10.749785,
       10.704592,
       10.739002,
       10.780206,
       10.858422,
       10.963359,
       11.058638,
       11.087819,
       11.070693,
       10.980195,
       10.979002,
       10.998811,
       10.989791,
       11.011555,
       11.051874,
       11.064229,
       11.077918,
       11.058165,
       11.085521,
       11.107345,
       11.110521,
       11.092428,
       11.115161,
       11.131548,
       11.131929,
       11.149514,
       11.163368,
       11.185032,
       11.209263,
       11.238725,
       11.262128,
       11.282946,
       11.307229,
       11.312216,
       11.306393,
       11.338167,
       11.371800,
       11.390927,
       11.379668,
       11.412221,
       11.447565,
       11.489442,
       11.517127,
       11.521955,
       11.533140,
       11.524795,
       11.537716,
       11.577795,
       11.597781,
       11.620011,
       11.645505,
       11.667165),
end = 1988, frequency = 1)
int.rate <- ts(c( 
       3.3000000,
       3.2500000,
       3.3000000,
       3.4500000,
       3.6000000,
       3.5000000,
       3.5500000,
       3.8000000,
       3.9500000,
       3.7700000,
       3.8000000,
       3.9000000,
       3.9000000,
       4.0000000,
       4.1000000,
       4.1500000,
       4.0500000,
       4.0500000,
       4.7500000,
       4.7500000,
       5.1000000,
       5.1700000,
       4.7100000,
       4.6100000,
       4.6600000,
       4.5000000,
       4.4000000,
       4.3000000,
       4.0500000,
       4.4200000,
       4.4000000,
       4.1000000,
       4.7000000,
       4.1500000,
       3.9900000,
       3.5000000,
       3.2000000,
       3.0800000,
       3.0000000,
       2.7500000,
       2.7000000,
       2.6500000,
       2.6500000,
       2.6500000,
       2.6000000,
       2.5500000,
       2.4300000,
       2.5000000,
       2.8000000,
       2.7400000,
       2.5800000,
       2.6700000,
       3.0000000,
       3.1500000,
       3.0000000,
       3.0400000,
       3.0900000,
       3.6800000,
       3.6100000,
       4.1000000,
       4.5500000,
       4.2200000,
       4.4200000,
       4.1600000,
       4.3300000,
       4.3500000,
       4.7500000,
       4.9500000,
       5.9300000,
       6.5400000,
       7.6000000,
       6.0990000,
       5.9890000,
       6.6590000,
       7.3490000,
       7.3390000,
       7.1390000,
       7.4190000,
       8.2490000,
       9.0990000,
       11.169000,
       13.229000,
       12.589000,
       11.199000,
       12.349000,
       11.109000,
       8.4990000,
       8.9990000,
       9.3390000),
end = 1988, frequency = 1)
nom.wages <- ts(c( 
       6.1882641,
       6.2363696,
       6.2859981,
       6.3062753,
       6.2878586,
       6.3297209,
       6.3578423,
       6.3935908,
       6.3062753,
       6.3952616,
       6.4785096,
       6.4488894,
       6.4785096,
       6.5352413,
       6.5453497,
       6.4937538,
       6.6214057,
       6.7833252,
       7.0094089,
       7.1647204,
       7.3343294,
       7.2413663,
       7.1569564,
       7.2463681,
       7.2633296,
       7.2793188,
       7.2970910,
       7.3145528,
       7.3356340,
       7.3414839,
       7.3051882,
       7.2218358,
       7.0475172,
       6.9902565,
       7.0501225,
       7.1033221,
       7.1600692,
       7.2269360,
       7.1670379,
       7.2174434,
       7.2668273,
       7.4103471,
       7.6123368,
       7.7617450,
       7.8308230,
       7.8308230,
       7.8308230,
       7.9348716,
       8.0189547,
       8.0375432,
       8.1022836,
       8.1909089,
       8.2511421,
       8.3072126,
       8.3243363,
       8.3793095,
       8.4314174,
       8.4734503,
       8.5063344,
       8.5604442,
       8.5852256,
       8.6137753,
       8.6534708,
       8.6860917,
       8.7316592,
       8.7623330,
       8.8013189,
       8.8363739,
       8.9020473,
       8.9586687,
       9.0057732,
       9.0528535,
       9.1354850,
       9.2086877,
       9.2689518,
       9.3451060,
       9.4377968,
       9.5272178,
       9.6124693,
       9.6899071,
       9.7590436,
       9.8559840,
       9.8938128,
       9.9634555,
       10.018269,
       10.050728,
       10.075372,
       10.101049,
       10.130371),
end = 1988, frequency = 1)
gnp.def <- ts(c( 
       3.2542430,
       3.2347492,
       3.2148678,
       3.1780538,
       3.1986731,
       3.1354942,
       3.1223649,
       3.0955776,
       3.1000923,
       3.1311369,
       3.1612467,
       3.2068032,
       3.1986731,
       3.2347492,
       3.2464910,
       3.2580965,
       3.2771447,
       3.3032170,
       3.3428618,
       3.3357696,
       3.3707382,
       3.3978585,
       3.3911470,
       3.4307562,
       3.4372078,
       3.4468079,
       3.4812401,
       3.5973123,
       3.8066625,
       3.9627161,
       3.9852735,
       4.1157798,
       3.9550825,
       3.9019727,
       3.9259259,
       3.9140210,
       3.9318256,
       3.9357395,
       3.9120230,
       3.9199912,
       3.9239516,
       3.8979241,
       3.8022081,
       3.6938670,
       3.6712245,
       3.7424202,
       3.7518543,
       3.7541989,
       3.7954892,
       3.7819143,
       3.7658405,
       3.7819143,
       3.8543939,
       3.9702919,
       4.0395363,
       4.0638854,
       4.0893320,
       4.2002050,
       4.3121405,
       4.3770141,
       4.3707129,
       4.3845235,
       4.4496853,
       4.4716388,
       4.4807401,
       4.4953553,
       4.5097600,
       4.5432948,
       4.5798524,
       4.6051702,
       4.6210435,
       4.6376374,
       4.6501436,
       4.6615505,
       4.6746962,
       4.6895113,
       4.7086289,
       4.7353209,
       4.7672890,
       4.8064770,
       4.8535915,
       4.9074945,
       4.9717756,
       5.0179885,
       5.0805088,
       5.1675202,
       5.2611455,
       5.3232569,
       5.3876964,
       5.4579762,
       5.5429079,
       5.6293890,
       5.7218309,
       5.7837063,
       5.8219651,
       5.8578857,
       5.8871651,
       5.9129787,
       5.9441231,
       5.9768030),
end = 1988, frequency = 1)
money.stock <-  ts(c( 
       1.2809338,
       1.3660917,
       1.4060970,
       1.4883996,
       1.4492692,
       1.4539530,
       1.4883996,
       1.4701758,
       1.5347144,
       1.6601310,
       1.8066481,
       1.8870696,
       2.0122328,
       2.1004689,
       2.1610215,
       2.2235419,
       2.3263016,
       2.4051417,
       2.4510051,
       2.4371160,
       2.5400259,
       2.5907670,
       2.6475922,
       2.7166795,
       2.7555697,
       2.7966714,
       2.8673306,
       3.0373539,
       3.1933529,
       3.2857865,
       3.4343097,
       3.5496174,
       3.4919517,
       3.5180911,
       3.6000482,
       3.6527340,
       3.7388594,
       3.7768903,
       3.8006444,
       3.8377304,
       3.8416005,
       3.8227545,
       3.7539647,
       3.5849069,
       3.4725874,
       3.5368931,
       3.6653549,
       3.7723011,
       3.8216606,
       3.8179321,
       3.8973154,
       4.0109630,
       4.1353265,
       4.2649309,
       4.4988092,
       4.6709579,
       4.8410325,
       4.9323133,
       4.9836066,
       4.9978877,
       4.9938282,
       5.0159545,
       5.0524168,
       5.1053392,
       5.1428325,
       5.1772790,
       5.2133040,
       5.2305737,
       5.2564532,
       5.3038023,
       5.3475836,
       5.3504353,
       5.3990673,
       5.4548937,
       5.5178544,
       5.5785971,
       5.6556421,
       5.7300998,
       5.8045324,
       5.8905386,
       5.9537627,
       5.9947093,
       6.0990686,
       6.2168746,
       6.3114079,
       6.3706122,
       6.4599264,
       6.5817039,
       6.7009965,
       6.7828573,
       6.8622155,
       6.9393739,
       7.0294186,
       7.1188699,
       7.2368443,
       7.3141543,
       7.4003523,
       7.4803232,
       7.5444435,
       7.5945765),
end = 1988, frequency = 1)
gnp.real <-  ts(c( 
       4.7604631,
       4.7883247,
       4.8138091,
       4.8690717,
       4.8782461,
       4.8331023,
       4.8243057,
       4.9000761,
       4.9067552,
       5.0225639,
       4.9863426,
       4.9416424,
       4.8504665,
       4.9972123,
       5.1113852,
       5.1089712,
       5.1896179,
       5.2470241,
       5.2459709,
       5.2517497,
       5.3161573,
       5.2122147,
       5.1316723,
       4.9712012,
       4.9522997,
       5.0388988,
       5.1328529,
       5.2626902,
       5.3141907,
       5.2621719,
       5.3442463,
       5.4258307,
       5.5748121,
       5.6964221,
       5.8203796,
       5.8897086,
       5.8726810,
       5.7449244,
       5.7362497,
       5.7798172,
       5.7810521,
       5.8729625,
       5.9490788,
       5.9791389,
       6.0229632,
       6.0088132,
       6.0822189,
       6.1005431,
       6.1147878,
       6.1032295,
       6.1652077,
       6.1897005,
       6.2089924,
       6.2724996,
       6.3117348,
       6.3649229,
       6.4261648,
       6.4893569,
       6.5150089,
       6.5604647,
       6.5857578,
       6.5792512,
       6.6067000,
       6.6552832,
       6.7059610,
       6.7005530,
       6.6879060,
       6.7356178,
       6.7812240,
       6.8328012,
       6.8572808,
       6.8556192,
       6.8747935,
       6.8489768,
       6.8840768,
       6.9496707,
       6.9826227,
       7.0096668,
       7.0455416,
       7.0888837),
end = 1988, frequency = 1)
stock.prices <- ts(c(
       1.5454326,
       1.6154200,
       1.5686159,
       1.5195132,
       1.4929041,
       1.4011830,
       1.1442228,
       1.2178757,
       1.4158532,
       1.6505799,
       1.8325815,
       1.7749524,
       1.7281094,
       1.5539252,
       1.5260563,
       1.6789640,
       1.7101878,
       1.6486586,
       1.6714733,
       1.6620304,
       1.6154200,
       1.7137979,
       1.5644405,
       1.4793292,
       1.5107219,
       1.4422020,
       1.4929041,
       1.6193882,
       1.8389611,
       1.8164521,
       2.0592388,
       2.1306098,
       1.9754690,
       1.9530276,
       2.1961128,
       2.2659211,
       2.0592388,
       2.0515563,
       2.2731563,
       2.2353763,
       2.2235419,
       2.2544447,
       2.1412419,
       2.0893919,
       2.1174596,
       2.2481289,
       2.1400662,
       2.0202222,
       2.1724764,
       2.0769384,
       1.9257074,
       2.1294215,
       2.1482677,
       2.2027648,
       2.4114395,
       2.5329028,
       2.7304638,
       2.9932291,
       3.2588655,
       3.0459500,
       2.6144719,
       1.9358598,
       2.1927702,
       2.2864557,
       2.3608540,
       2.7389027,
       2.7350166,
       2.4414771,
       2.4898942,
       2.3997118,
       2.2844211,
       2.1598688,
       2.4423470,
       2.5233258,
       2.7186604,
       2.8379082,
       2.7193198,
       2.7427736,
       2.7232672,
       2.9123507,
       3.1063788,
       3.1986731,
       3.2080171,
       3.3908103,
       3.7010550,
       3.8420296,
       3.7927889,
       3.8338452,
       4.0496958,
       4.0226695,
       4.1937373,
       4.1332447,
       4.2466364,
       4.3990067,
       4.4792668,
       4.4457054,
       4.5210274,
       4.5920849,
       4.5833335,
       4.4214877,
       4.5879223,
       4.6931811,
       4.6768395,
       4.4170317,
       4.4562060,
       4.6250708,
       4.5870062,
       4.5645565,
       4.6348261,
       4.7772730,
       4.8523427,
       4.7850722,
       5.0777330,
       5.0780447,
       5.2302526,
       5.4652714,
       5.6588897,
       5.5827065),
end = 1988, frequency = 1)
gnp.capita <- ts(c(
       7.1631724,
       7.1701195,
       7.1793080,
       7.2196420,
       7.2086003,
       7.1444072,
       7.1212525,
       7.1831117,
       7.1770188,
       7.2936977,
       7.2449415,
       7.1815919,
       7.0707241,
       7.2041493,
       7.3011478,
       7.2793188,
       7.3453648,
       7.3889461,
       7.3740019,
       7.3677086,
       7.4211775,
       7.3065314,
       7.2181768,
       7.0509894,
       7.0264268,
       7.1066061,
       7.1936858,
       7.3172124,
       7.3626453,
       7.3024964,
       7.3765081,
       7.4500796,
       7.5893358,
       7.6998424,
       7.8099471,
       7.8674886,
       7.8391316,
       7.7012002,
       7.6732231,
       7.6998424,
       7.6834037,
       7.7587605,
       7.8180279,
       7.8308230,
       7.8582542,
       7.8264431,
       7.8823149,
       7.8830694,
       7.8792915,
       7.8512720,
       7.8965527,
       7.9006366,
       7.9035963,
       7.9519114,
       7.9765954,
       8.0159878,
       8.0649509,
       8.1164171,
       8.1312365,
       8.1667843,
       8.1822797,
       8.1650793,
       8.1785483,
       8.2164263,
       8.2575593,
       8.2430147,
       8.2205079,
       8.2587175,
       8.2942660,
       8.3352474,
       8.3486913,
       8.3350953,
       8.3438697,
       8.3077558,
       8.3331023,
       8.3893616,
       8.4127477,
       8.4300848,
       8.4564770,
       8.4908482),
end = 1988, frequency = 1)
real.wages <- ts(c(
       2.9693883,
       3.0174938,
       3.0277153,
       3.0106209,
       2.9922261,
       3.0339910,
       3.0257764,
       3.0262615,
       2.9739978,
       3.0629235,
       3.1112906,
       3.0814511,
       3.0773123,
       3.1441523,
       3.1406980,
       3.0791539,
       3.1341890,
       3.1350593,
       3.2007119,
       3.2172745,
       3.2398542,
       3.2596338,
       3.2410286,
       3.3127304,
       3.3275508,
       3.3185401,
       3.3268330,
       3.3631493,
       3.3978585,
       3.4038605,
       3.3931652,
       3.4018638,
       3.3364811,
       3.3318473,
       3.3586378,
       3.3874365,
       3.4343097,
       3.4657359,
       3.4245883,
       3.4892083,
       3.5292974,
       3.6238075,
       3.7244879,
       3.8144102,
       3.8661885,
       3.8437442,
       3.7618975,
       3.7316995,
       3.7409974,
       3.7693067,
       3.8242841,
       3.8368683,
       3.8753590,
       3.9239516,
       3.9361301,
       3.9947084,
       4.0321145,
       4.0390080,
       4.0449792,
       4.0911729,
       4.0999952,
       4.1183866,
       4.1470951,
       4.1675950,
       4.2002050,
       4.2137559,
       4.2244952,
       4.2312037,
       4.2557545,
       4.2600002,
       4.2496374,
       4.2541893,
       4.3052264,
       4.3180859,
       4.2736654,
       4.2624703,
       4.2991392,
       4.3255607,
       4.3376476,
       4.3075800,
       4.2500959,
       4.2488618,
       4.2269076,
       4.2649311,
       4.2774775,
       4.2749452,
       4.2811725,
       4.2710033,
       4.2597845),
end = 1988, frequency = 1)
unemp <- ts(c(
       1.3862944,
       1.6863990,
       1.0986123,
       2.4595888,
       2.9123507,
       2.6173958,
       2.6672282,
       2.6741486,
       2.5176965,
       1.8718022,
       1.6094379,
       1.3862944,
       1.3083328,
       1.3609766,
       1.6863990,
       1.4586150,
      0.53062825,
       1.0296194,
       2.0794415,
       1.6292405,
       1.7749524,
       1.9021075,
       1.5260563,
       1.4586150,
       2.0668628,
       2.1400662,
       1.6292405,
       1.5260563,
      0.33647224,
      0.33647224,
       1.6486586,
       2.4595888,
       1.9021075,
      0.87546874,
       1.6094379,
       1.1631508,
      0.58778666,
       1.1939225,
       1.4350845,
       1.1631508,
       2.1633230,
       2.7663191,
       3.1612467,
       3.2148678,
       3.0773123,
       3.0007198,
       2.8273136,
       2.6602595,
       2.9444390,
       2.8449094,
       2.6810215,
       2.2925348,
       1.5475625,
      0.64185389,
      0.18232156,
      0.64185389,
       1.3609766,
       1.3609766,
       1.3350011,
       1.7749524,
       1.6677068,
       1.1939225,
       1.0986123,
       1.0647107,
       1.7047481,
       1.4816045,
       1.4109870,
       1.4586150,
       1.9169226,
       1.7047481,
       1.7047481,
       1.9021075,
       1.7047481,
       1.7404662,
       1.6486586,
       1.5040774,
       1.3350011,
       1.3350011,
       1.2809338,
       1.2527630,
       1.5892352,
       1.7749524,
       1.7227666,
       1.5892352,
       1.7227666,
       2.1400662,
       2.0412203,
       1.9600948,
       1.8082888,
       1.7578579,
       1.9600948,
       2.0281482,
       2.2721259,
       2.2617631,
       2.0149030,
       1.9740810,
       1.9459101,
       1.8245493,
       1.7047481),
end = 1988, frequency = 1)
NelPlo <- ts.union (cpi, ip, gnp.nom, vel, emp, int.rate, nom.wages,
                    gnp.def, money.stock, gnp.real, stock.prices, 
                    gnp.capita, real.wages, unemp)
